TestGoldensCommand class
Command that runs Flutter Golden tests, comparing new test output to existing Golden files.
Failure scene images are generated for Golden mismatches, as per usual Flutter Golden behavior.
- Inheritance
-
- Object
- GoldensCommand
- TestGoldensCommand
- Implemented types
Constructors
- TestGoldensCommand({GoldensCommandEnvironment environment = const GoldensCommandEnvironment()})
Properties
-
command
→ List<
String> -
The specific Flutter golden command that's run by this command.
no setteroverride
- containerTestDirectoryPath → String
-
no setterinherited
- containerWorkingDirectory → String
-
The path within the Docker Container where the command should be run.
no setterinherited
- dockerFilePath → String?
-
no setterinherited
- dockerImageName → String
-
no setterinherited
- dockerVerbosity → DockerVerbosity
-
no setterinherited
- flutterVersion → String?
-
The Flutter version to install in the Docker Container, e.g.,
"3.44.6","stable", or any git ref (tag/branch/commit) of the flutter/flutter repository.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hostTestDirectoryPath → String
-
no setterinherited
-
mountPaths
→ Set<
String> -
Docker mount paths from the host machine into the Docker Container, which allows the Docker Container
to alter the host file system.
no setterinherited
- packageDirectory → String
-
no setterinherited
- packagePathFromProjectRoot → String
-
no setterinherited
- pathToProjectRoot → String
-
The path from where this command is running, to the directory that should be copied over into the
Docker Image.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silent → bool
-
Whether the command is running in silent mode (
--silent): no progress output, but errors (including from sub-processes) and a failing exit code still surface.no setterinherited - testBaseDirectory → String
-
no setterinherited
-
testCommandArguments
→ List<
String> -
no setterinherited
- ubuntuVersion → String?
-
The Ubuntu version (a Docker Hub
ubuntuimage tag, e.g.,"24.04","noble", or"latest") to base the Docker Image on.no setterinherited
Methods
-
assembleDockerContainerRequest(
) → RunDockerContainerRequest -
Uses parsed arguments to assemble a RunDockerContainerRequest, which is then used to tell Docker how to
build an Image and then run in a Container.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseArguments(
List< String> arguments) → void -
inherited
-
run(
) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
useFlutterVersionIfUnset(
String version) → void -
Sets the Flutter version to
versiononly if one wasn't already provided viaargFlutterVersion, so an explicit--flutter-versionalways wins over an auto-detected default (e.g. from FVM config).inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited